@@ -10,41 +10,36 @@ This example illustrates how to print the data set in your own format.
 # authors : Guillaume Lemaitre <g.lemaitre58@gmail.com>
 # license : MIT
 
-import pydicom
-from pydicom.data import get_testdata_file
+from pydicom import examples
 
 print(__doc__)
 
 
-def myprint(dataset, indent=0):
+def myprint(ds, indent=0):
     """Go through all items in the dataset and print them with custom format
 
     Modelled after Dataset._pretty_str()
     """
-    dont_print = ['Pixel Data', 'File Meta Information Version']
+    dont_print = ["Pixel Data", "File Meta Information Version"]
 
     indent_string = "   " * indent
     next_indent_string = "   " * (indent + 1)
 
-    for data_element in dataset:
-        if data_element.VR == "SQ":   # a sequence
-            print(indent_string, data_element.name)
-            for sequence_item in data_element.value:
+    for elem in ds:
+        if elem.VR == "SQ":  # a sequence
+            print(indent_string, elem.name)
+            for sequence_item in elem.value:
                 myprint(sequence_item, indent + 1)
                 print(next_indent_string + "---------")
         else:
-            if data_element.name in dont_print:
+            if elem.name in dont_print:
                 print("""<item not printed -- in the "don't print" list>""")
             else:
-                repr_value = repr(data_element.value)
+                repr_value = repr(elem.value)
                 if len(repr_value) > 50:
                     repr_value = repr_value[:50] + "..."
-                print("{0:s} {1:s} = {2:s}".format(indent_string,
-                                                   data_element.name,
-                                                   repr_value))
+                print(f"{indent_string} {elem.name} = {repr_value}")
 
 
-filename = get_testdata_file('MR_small.dcm')
-ds = pydicom.dcmread(filename)
-
+ds = examples.mr
 myprint(ds)
