@@ -12,23 +12,16 @@ This examples illustrates how to find the differences between two DICOM files.
 
 import difflib
 
-import pydicom
-from pydicom.data import get_testdata_files
+from pydicom import examples
 
 print(__doc__)
 
-filename_mr = get_testdata_files('MR_small.dcm')[0]
-filename_ct = get_testdata_files('CT_small.dcm')[0]
-
-datasets = tuple([pydicom.dcmread(filename, force=True)
-                  for filename in (filename_mr, filename_ct)])
-
 # difflib compare functions require a list of lines, each terminated with
 # newline character massage the string representation of each dicom dataset
 # into this form:
 rep = []
-for dataset in datasets:
-    lines = str(dataset).split("\n")
+for ds in [examples.mr, examples.ct]:
+    lines = str(ds).split("\n")
     lines = [line + "\n" for line in lines]  # add the newline to end
     rep.append(lines)
 
